@@ -210,6 +210,10 @@ def write_root_rels(workbook):
 def write_workbook(workbook):
     """Write the core workbook xml."""
     root = Element('{%s}workbook' % SHEET_MAIN_NS)
+    if LXML:
+        _nsmap = {'r':REL_NS}
+        root = Element('{%s}workbook' % SHEET_MAIN_NS, nsmap=_nsmap)
+
     SubElement(root, '{%s}fileVersion' % SHEET_MAIN_NS,
                {'appName': 'xl', 'lastEdited': '4', 'lowestEdited': '4', 'rupBuild': '4505'})
     SubElement(root, '{%s}workbookPr' % SHEET_MAIN_NS,
